==> aws-cdk.aws-apigatewayv2-authorizers-alpha-2.16.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaResponseType(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizerProps(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizerProps(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizerProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.userPoolClients))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_cognito_IUserPoolClient(p.userPoolClients);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizerProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.responseTypes))
        _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaResponseType(p.responseTypes);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpIamAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizer(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpIamAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizer };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-apigatewayv2-authorizers-alpha-2.18.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaResponseType(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizerProps(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizerProps(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizerProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.userPoolClients))
        require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_cognito_IUserPoolClient(p.userPoolClients);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizerProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.responseTypes))
        _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaResponseType(p.responseTypes);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpIamAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizer(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpIamAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizer };
module.exports.DeprecationError = DeprecationError;
